# ProtoTorch Releases

## Release 0.2.0

### Includes
- Fixes in example scripts.

## Release 0.1.1-dev0

### Includes
- Minor bugfixes.
- 100% line coverage.

## Release 0.1.0-dev0

Initial public release of ProtoTorch.
